@@ -521,7 +521,9 @@ pub fn query_download_logo(deps: Deps) -> StdResult<DownloadLogoResponse> {
 
 #[cfg(test)]
 mod tests {
-    use cosmwasm_std::testing::{mock_dependencies, mock_env, mock_info};
+    use cosmwasm_std::testing::{
+        mock_dependencies, mock_dependencies_with_balance, mock_env, mock_info,
+    };
     use cosmwasm_std::{coins, from_binary, Addr, CosmosMsg, StdError, SubMsg, WasmMsg};
 
     use super::*;
@@ -600,7 +602,7 @@ mod tests {
 
         #[test]
         fn basic() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let amount = Uint128::from(11223344u128);
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
@@ -635,7 +637,7 @@ mod tests {
 
         #[test]
         fn mintable() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let amount = Uint128::new(11223344);
             let minter = String::from("asmodat");
             let limit = Uint128::new(511223344);
@@ -682,7 +684,7 @@ mod tests {
 
         #[test]
         fn mintable_over_cap() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let amount = Uint128::new(11223344);
             let minter = String::from("asmodat");
             let limit = Uint128::new(11223300);
@@ -714,7 +716,7 @@ mod tests {
 
             #[test]
             fn basic() {
-                let mut deps = mock_dependencies(&[]);
+                let mut deps = mock_dependencies();
                 let instantiate_msg = InstantiateMsg {
                     name: "Cash Token".to_string(),
                     symbol: "CASH".to_string(),
@@ -754,7 +756,7 @@ mod tests {
 
             #[test]
             fn invalid_marketing() {
-                let mut deps = mock_dependencies(&[]);
+                let mut deps = mock_dependencies();
                 let instantiate_msg = InstantiateMsg {
                     name: "Cash Token".to_string(),
                     symbol: "CASH".to_string(),
@@ -785,7 +787,7 @@ mod tests {
 
     #[test]
     fn can_mint_by_minter() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
 
         let genesis = String::from("genesis");
         let amount = Uint128::new(11223344);
@@ -832,7 +834,7 @@ mod tests {
 
     #[test]
     fn others_cannot_mint() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         do_instantiate_with_minter(
             deps.as_mut(),
             &String::from("genesis"),
@@ -853,7 +855,7 @@ mod tests {
 
     #[test]
     fn no_one_mints_if_minter_unset() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         do_instantiate(deps.as_mut(), &String::from("genesis"), Uint128::new(1234));
 
         let msg = ExecuteMsg::Mint {
@@ -868,7 +870,7 @@ mod tests {
 
     #[test]
     fn instantiate_multiple_accounts() {
-        let mut deps = mock_dependencies(&[]);
+        let mut deps = mock_dependencies();
         let amount1 = Uint128::from(11223344u128);
         let addr1 = String::from("addr0001");
         let amount2 = Uint128::from(7890987u128);
@@ -910,7 +912,7 @@ mod tests {
 
     #[test]
     fn queries_work() {
-        let mut deps = mock_dependencies(&coins(2, "token"));
+        let mut deps = mock_dependencies_with_balance(&coins(2, "token"));
         let addr1 = String::from("addr0001");
         let amount1 = Uint128::from(12340000u128);
 
@@ -947,7 +949,7 @@ mod tests {
 
     #[test]
     fn transfer() {
-        let mut deps = mock_dependencies(&coins(2, "token"));
+        let mut deps = mock_dependencies_with_balance(&coins(2, "token"));
         let addr1 = String::from("addr0001");
         let addr2 = String::from("addr0002");
         let amount1 = Uint128::from(12340000u128);
@@ -1007,7 +1009,7 @@ mod tests {
 
     #[test]
     fn burn() {
-        let mut deps = mock_dependencies(&coins(2, "token"));
+        let mut deps = mock_dependencies_with_balance(&coins(2, "token"));
         let addr1 = String::from("addr0001");
         let amount1 = Uint128::from(12340000u128);
         let burn = Uint128::from(76543u128);
@@ -1056,7 +1058,7 @@ mod tests {
 
     #[test]
     fn send() {
-        let mut deps = mock_dependencies(&coins(2, "token"));
+        let mut deps = mock_dependencies_with_balance(&coins(2, "token"));
         let addr1 = String::from("addr0001");
         let contract = String::from("addr0002");
         let amount1 = Uint128::from(12340000u128);
@@ -1133,7 +1135,7 @@ mod tests {
 
         #[test]
         fn update_unauthorised() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1187,7 +1189,7 @@ mod tests {
 
         #[test]
         fn update_project() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1240,7 +1242,7 @@ mod tests {
 
         #[test]
         fn clear_project() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1293,7 +1295,7 @@ mod tests {
 
         #[test]
         fn update_description() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1346,7 +1348,7 @@ mod tests {
 
         #[test]
         fn clear_description() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1399,7 +1401,7 @@ mod tests {
 
         #[test]
         fn update_marketing() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1452,7 +1454,7 @@ mod tests {
 
         #[test]
         fn update_marketing_invalid() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1509,7 +1511,7 @@ mod tests {
 
         #[test]
         fn clear_marketing() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1562,7 +1564,7 @@ mod tests {
 
         #[test]
         fn update_logo_url() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1611,7 +1613,7 @@ mod tests {
 
         #[test]
         fn update_logo_png() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1661,7 +1663,7 @@ mod tests {
 
         #[test]
         fn update_logo_svg() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1712,7 +1714,7 @@ mod tests {
 
         #[test]
         fn update_logo_png_oversized() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1762,7 +1764,7 @@ mod tests {
 
         #[test]
         fn update_logo_svg_oversized() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1819,7 +1821,7 @@ mod tests {
 
         #[test]
         fn update_logo_png_invalid() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
@@ -1869,7 +1871,7 @@ mod tests {
 
         #[test]
         fn update_logo_svg_invalid() {
-            let mut deps = mock_dependencies(&[]);
+            let mut deps = mock_dependencies();
             let instantiate_msg = InstantiateMsg {
                 name: "Cash Token".to_string(),
                 symbol: "CASH".to_string(),
